Documentation
¶
Overview ¶
Package process implements an simple alternative to os/exec built above os.Process. It adds the possibility to asynchronously monitor the state of the child process.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Process ¶
type Process struct {
// contains filtered or unexported fields
}
Process represents a child process whose state is monitored.
func Start ¶
Start creates a new child process and starts a monitoring routine to keep track of its state.
func (*Process) C ¶
C retuns a channel which will be notified of the process exit code on its termination.
func (*Process) ExitCode ¶
ExitCode returns the exit code of the process if it exited and panics if the process is still running.
Click to show internal directories.
Click to hide internal directories.